docstripy API
=============

docstripy.difference
--------------------

.. automodule:: docstripy.difference
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.file\_parser
----------------------

.. automodule:: docstripy.file_parser
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.line\_break
---------------------

.. automodule:: docstripy.line_break
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.lines\_routines
-------------------------

.. automodule:: docstripy.lines_routines
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.main
--------------

.. automodule:: docstripy.main
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.write
---------------

.. automodule:: docstripy.write
   :members:
   :undoc-members:
   :show-inheritance:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   docstripy.parse_doc
   docstripy.build_doc
   docstripy.google
   docstripy.numpy
   docstripy.rest
